package categoryservicelogic

import (
	"code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/usecase"
	"context"

	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type ListLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ListLogic {
	return &ListLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// List 建立 product 分類
func (l *ListLogic) List(in *product.ListCategoryReq) (*product.ListCategoryResp, error) {
	q := usecase.CategoryQueryParams{
		PageSize:  in.GetPageSize(),
		PageIndex: in.GetPageIndex(),
	}

	if len(in.GetIds()) > 0 {
		q.ID = in.GetIds()
	}

	category, total, err := l.svcCtx.CategoryUseCase.ListCategory(l.ctx, q)
	if err != nil {
		return nil, err
	}

	res := make([]*product.Category, 0, len(category))
	for _, c := range category {
		res = append(res, &product.Category{
			Id:         c.ID.Hex(),
			Name:       c.Name,
			CreateTime: c.CreatedAt,
			UpdateTime: c.UpdatedAt,
		})
	}

	return &product.ListCategoryResp{
		Total: total,
		Data:  res,
	}, nil
}
