package kycservicelogic

import (
	"context"

	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type FindLatestByUidLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewFindLatestByUidLogic(ctx context.Context, svcCtx *svc.ServiceContext) *FindLatestByUidLogic {
	return &FindLatestByUidLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// FindLatestByUid 根據使用者 UID 查詢最新 KYC 紀錄
func (l *FindLatestByUidLogic) FindLatestByUid(in *product.FindLatestKycByUIDReq) (*product.Kyc, error) {
	kycInfo, err := l.svcCtx.KYCUseCase.FindLatestByUID(l.ctx, in.GetUid())
	if err != nil {
		return nil, err
	}

	return &product.Kyc{
		Id:                 kycInfo.ID.Hex(),
		Uid:                kycInfo.UID,
		CountryRegion:      kycInfo.CountryRegion,
		Name:               kycInfo.Name,
		Identification:     kycInfo.Identification,
		IdentificationType: kycInfo.IdentificationType,
		Address:            kycInfo.Address,
		PostalCode:         kycInfo.PostalCode,
		// 上傳文件網址（可為 object storage 的 URL）
		IdFrontImage:     kycInfo.IDFrontImage,
		IdBackImage:      kycInfo.IDBackImage,
		BankStatementImg: kycInfo.BankStatementImg,
		BankCode:         kycInfo.BankCode,
		BankName:         kycInfo.BankName,
		BranchCode:       kycInfo.BranchCode,
		BranchName:       kycInfo.BranchName,
		BankAccount:      kycInfo.BankAccount,
		Status:           kycInfo.Status.ToString(),
		RejectReason:     kycInfo.RejectReason,
		UpdatedAt:        kycInfo.UpdatedAt,
		CreatedAt:        kycInfo.CreatedAt,
	}, nil
}
