package kycservicelogic

import (
	"code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/usecase"
	"context"

	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type ListLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ListLogic {
	return &ListLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// List 分頁查詢 Kyc 清單（後台審核用）
func (l *ListLogic) List(in *product.ListKycReq) (*product.ListKycResp, error) {
	filter := usecase.KYCQueryParams{
		UID:       in.Uid,
		Country:   in.Country,
		Status:    in.Status,
		PageSize:  in.GetPageSize(),
		PageIndex: in.GetPageIndex(),
	}

	list, total, err := l.svcCtx.KYCUseCase.List(l.ctx, filter)
	if err != nil {
		return nil, err
	}

	result := make([]*product.Kyc, 0, len(list))
	for _, kycInfo := range list {
		result = append(result, &product.Kyc{
			Id:                 kycInfo.ID.Hex(),
			Uid:                kycInfo.UID,
			CountryRegion:      kycInfo.CountryRegion,
			Name:               kycInfo.Name,
			Identification:     kycInfo.Identification,
			IdentificationType: kycInfo.IdentificationType,
			Address:            kycInfo.Address,
			PostalCode:         kycInfo.PostalCode,
			IdFrontImage:       kycInfo.IDFrontImage,
			IdBackImage:        kycInfo.IDBackImage,
			BankStatementImg:   kycInfo.BankStatementImg,
			BankCode:           kycInfo.BankCode,
			BankName:           kycInfo.BankName,
			BranchCode:         kycInfo.BranchCode,
			BranchName:         kycInfo.BranchName,
			BankAccount:        kycInfo.BankAccount,
			Status:             kycInfo.Status.ToString(),
			RejectReason:       kycInfo.RejectReason,
			UpdatedAt:          kycInfo.UpdatedAt,
			CreatedAt:          kycInfo.CreatedAt,
		})
	}

	return &product.ListKycResp{
		Total: total,
		List:  result,
	}, nil
}
