package tagservicelogic

import (
	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"
	"code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/entity"
	domainProduct "code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/product"
	"code.30cm.net/digimon/library-go/errs"
	"context"

	"github.com/zeromicro/go-zero/core/logx"
)

type CreateLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewCreateLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CreateLogic {
	return &CreateLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// Create 建立 tags
func (l *CreateLogic) Create(in *product.CreateTagsReq) (*product.OKResp, error) {
	showType, status := domainProduct.StringToShowType(in.GetShowType())
	if !status {
		return nil, errs.InvalidFormat("failed to convert show types")
	}

	itemTypes, itemStatus := domainProduct.StringToItemType(in.GetTypes())
	if !itemStatus {
		return nil, errs.InvalidFormat("failed to convert types")
	}
	insert := &entity.Tags{
		Types:    itemTypes,
		Name:     in.GetName(),
		ShowType: showType,
	}

	if in.Cover != nil {
		insert.Cover = in.Cover
	}

	err := l.svcCtx.TagsUseCase.Create(l.ctx, insert)
	if err != nil {
		return nil, err
	}

	return &product.OKResp{}, nil
}
