package tagservicelogic

import (
	"context"

	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetLogic {
	return &GetLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// Get 取得 tags
func (l *GetLogic) Get(in *product.TagsReq) (*product.Tags, error) {
	tag, err := l.svcCtx.TagsUseCase.GetByID(l.ctx, in.GetId())
	if err != nil {
		return nil, err
	}

	result := &product.Tags{Id: tag.ID.Hex(),
		Types:     tag.Types.ToString(),
		Name:      tag.Name,
		ShowType:  tag.ShowType.ToString(),
		UpdateAt:  tag.UpdatedAt,
		CreatedAt: tag.CreatedAt,
	}
	if tag.Cover != nil {
		result.Cover = *tag.Cover
	}

	return result, nil
}
