package tagservicelogic

import (
	domain "code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/product"
	"code.30cm.net/digimon/app-cloudep-product-service/pkg/domain/usecase"
	"code.30cm.net/digimon/library-go/errs"
	"context"

	"code.30cm.net/digimon/app-cloudep-product-service/gen_result/pb/product"
	"code.30cm.net/digimon/app-cloudep-product-service/internal/svc"

	"github.com/zeromicro/go-zero/core/logx"
)

type ModifyLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewModifyLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ModifyLogic {
	return &ModifyLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

// Modify 修改 tags
func (l *ModifyLogic) Modify(in *product.ModifyTagsReq) (*product.OKResp, error) {
	var params usecase.TagModifyParams

	if in.Types != nil {
		itemTypes, ok := domain.StringToItemType(in.GetTypes())
		if !ok {
			return nil, errs.InvalidFormat("failed to convert types")
		}
		params.Types = &itemTypes
	}
	if in.ShowType != nil {
		showType, ok := domain.StringToShowType(in.GetShowType())
		if !ok {
			return nil, errs.InvalidFormat("failed to convert show types")
		}
		params.ShowType = &showType
	}
	// 處理 name
	if in.Name != nil {
		params.Name = in.Name
	}
	// 處理 cover
	if in.Cover != nil {
		params.Cover = in.Cover
	}

	// 執行更新
	err := l.svcCtx.TagsUseCase.Update(l.ctx, in.GetId(), params)
	if err != nil {
		return nil, err
	}

	return &product.OKResp{}, nil
}
